@@ -100,7 +100,7 @@ lookupInstance xs n = headMay $ filter (`instanceMatches` n) xs
 -- the given 'TypeclassInstance'.
 instanceMatches :: TypeclassInstance -> Name -> Bool
 instanceMatches (TypeclassInstance _ typ _) n' =
-    case tailMay $ map (headMay . unAppsT) $ unAppsT typ of
+    case tailMay $ map (fmap unSigT . headMay . unAppsT) $ unAppsT typ of
         Nothing -> False
         Just xs -> not $ null [() | Just (ConT n) <- xs, n == n']
 
@@ -110,3 +110,8 @@ unAppsT = go []
   where
     go xs (AppT l x) = go (x : xs) l
     go xs ty = ty : xs
+
+-- | Remove any explicit kind signatures (i.e., 'SigT's) from a 'Type'.
+unSigT :: Type -> Type
+unSigT (SigT t _) = unSigT t
+unSigT t          = t
